@@ -40,9 +40,11 @@ def open_webdriver(driver_name: str = DEFAULT_DRIVER, headless: bool = True) ->
             opts.add_argument("--headless")
             opts.add_argument("--disable-gpu")
             opts.add_argument("--disable-dev-shm-usage")
+            opts.add_argument('--ignore-certificate-errors')
         elif driver_name == "firefox":
             opts = FirefoxOptions()
             opts.headless = True
+            opts.accept_insecure_certs(True)
         else:
             raise NotImplementedError(
                 f"{__file__}: headless mode for {driver_name} is not supported."
